@@ -1,11 +1,9 @@
 # -*- coding: UTF-8 -*-
-
-#########################################################
 # Name: audiodialogs.py
 # Porpose: Dialog for choice and settings audio parameters
 # Compatibility: Python3, wxPython Phoenix
-# Author: Gianluca Pernigoto <jeanlucperni@gmail.com>
-# Copyright: (c) 2018/2020 Gianluca Pernigoto <jeanlucperni@gmail.com>
+# Author: Gianluca Pernigotto <jeanlucperni@gmail.com>
+# Copyright: (c) 2018/2021 Gianluca Pernigotto <jeanlucperni@gmail.com>
 # license: GPL3
 # Rev: April.06.2020 *PEP8 compatible*
 #########################################################
@@ -45,9 +43,6 @@ class AudioSettings(wx.Dialog):
         but here they are assigned by reference with the instance-object.
 
         """
-        wx.Dialog.__init__(self, parent, -1, title=title,
-                           style=wx.DEFAULT_DIALOG_STYLE
-                           )
         data = TypeAudioParameters(audio_type)  # instance for audio param
         # set attributes:
         self.sample_rate = data.sample_rate
@@ -80,6 +75,9 @@ class AudioSettings(wx.Dialog):
         for d in self.bitdepth.values():
             bitdepth_list.append(d[0])
 
+        wx.Dialog.__init__(self, parent, -1, title=title,
+                           style=wx.DEFAULT_DIALOG_STYLE
+                           )
         self.rdb_bitrate = wx.RadioBox(self, wx.ID_ANY,
                                        ("Audio Bit-Rate"),
                                        choices=bitrate_list,
@@ -142,23 +140,23 @@ class AudioSettings(wx.Dialog):
         sizerBase = wx.BoxSizer(wx.VERTICAL)
         grid_sizer_1 = wx.FlexGridSizer(1, 4, 0, 0)  # radiobox
         sizerBase.Add(grid_sizer_1, 0, wx.ALL, 0)
-        grid_sizer_1.Add(self.rdb_bitrate, 0, wx.ALL, 15)
-        grid_sizer_1.Add(self.rdb_channels, 0, wx.ALL, 15)
-        grid_sizer_1.Add(self.rdb_sample_r, 0, wx.ALL, 15)
-        grid_sizer_1.Add(self.rdb_bitdepth, 0, wx.ALL, 15)
-
-        gridhelp = wx.GridSizer(1, 1, 0, 0)  # buttons
-        gridhelp.Add(btn_help, 0, wx.ALL, 5)
-
-        gridexit = wx.GridSizer(1, 3, 0, 0)  # buttons
-        gridexit.Add(self.btn_cancel, 0, wx.ALL, 5)
-        gridexit.Add(self.btn_ok, 0, wx.ALL, 5)
-        gridexit.Add(btn_reset, 0, wx.ALL, 5)
+        grid_sizer_1.Add(self.rdb_bitrate, 0, wx.ALL, 10)
+        grid_sizer_1.Add(self.rdb_channels, 0, wx.ALL, 10)
+        grid_sizer_1.Add(self.rdb_sample_r, 0, wx.ALL, 10)
+        grid_sizer_1.Add(self.rdb_bitdepth, 0, wx.ALL, 10)
 
         gridBtn = wx.GridSizer(1, 2, 0, 0)  # buttons
+        gridhelp = wx.GridSizer(1, 1, 0, 0)  # buttons
+        gridhelp.Add(btn_help, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
         gridBtn.Add(gridhelp)
-        gridBtn.Add(gridexit)
-        sizerBase.Add(gridBtn, 1, wx.ALL | wx.ALIGN_CENTRE, 10)
+
+        gridexit = wx.BoxSizer(wx.HORIZONTAL)
+        gridexit.Add(self.btn_cancel, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
+        gridexit.Add(self.btn_ok, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
+        gridexit.Add(btn_reset, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
+        gridBtn.Add(gridexit, 0, wx.ALL | wx.ALIGN_RIGHT | wx.RIGHT, 0)
+        sizerBase.Add(gridBtn, 0, wx.ALL | wx.EXPAND, 5)
+
         self.SetSizer(sizerBase)
         sizerBase.Fit(self)
         self.Layout()
