@@ -1,13 +1,11 @@
 # -*- coding: UTF-8 -*-
-
-#########################################################
 # Name: long_processing_task.py
 # Porpose: Console to show logging messages during processing
 # Compatibility: Python3, wxPython4 Phoenix
-# Author: Gianluca Pernigoto <jeanlucperni@gmail.com>
-# Copyright: (c) 2018/2020 Gianluca Pernigoto <jeanlucperni@gmail.com>
+# Author: Gianluca Pernigotto <jeanlucperni@gmail.com>
+# Copyright: (c) 2018/2021 Gianluca Pernigotto <jeanlucperni@gmail.com>
 # license: GPL3
-# Rev: April.06.2020 *PEP8 compatible*
+# Rev: Dec.14.2020 *PEP8 compatible*
 #########################################################
 # This file is part of Videomass.
 
@@ -36,19 +34,8 @@ from videomass3.vdms_threads.one_pass import OnePass
 from videomass3.vdms_threads.two_pass import TwoPass
 from videomass3.vdms_threads.two_pass_EBU import Loudnorm
 from videomass3.vdms_threads.picture_exporting import PicturesFromVideo
-from videomass3.vdms_utils.utils import time_human
-
-# Used colour
-YELLOW = 200, 183, 47
-RED = 210, 24, 20
-VIOLET = 164, 30, 164
-GREEN = 30, 164, 30
-AZURE = 30, 62, 164
-
-# get videomass wx.App attribute
-get = wx.GetApp()
-OS = get.OS
-LOGDIR = get.LOGdir
+from videomass3.vdms_utils.utils import milliseconds2timeformat
+from videomass3.vdms_utils.utils import get_milliseconds
 
 
 def pairwise(iterable):
@@ -63,7 +50,7 @@ def pairwise(iterable):
               bitrate= 435.0kbits/s speed=5.15x  "
     in a list as:
     iterable = ['frame', '1178', 'fps', '155', 'q', '29.0', 'size', '2072kB',
-                'time', '00:00:39.02', 'bitrate', '435.0kbits/s', s'peed',
+                'time', '00:00:39.02', 'bitrate', '435.0kbits/s', speed',
                 '5.15x']
     for x, y in pairwise(iterable):
         print(x,y)
@@ -86,6 +73,60 @@ class Logging_Console(wx.Panel):
     process and close the panel at the end.
 
     """
+    # get videomass wx.App attribute
+    get = wx.GetApp()
+    OS = get.OS
+    LOGDIR = get.LOGdir
+
+    # used msg on text
+    MSG_done = _('[Videomass]: DONE !\n')
+    MSG_failed = _('[Videomass]: FAILED !\n')
+    MSG_taskfailed = _('\n[Videomass]: Sorry, task failed !\n')
+    MSG_interrupted = _('\n[Videomass]: Interrupted Process !\n')
+    MSG_completed = _('\n[Videomass]: Successfully completed !\n')
+    MSG_unfinished = _('\n[Videomass]: completed, but not everything '
+                       'was successful.\n')
+
+    # Colors used in HTML
+    if get.THEME == 'Breeze-Blues':
+        BACKGROUND = '#11303eff'  # SOLARIZED background color for blues icons
+        NORM_TEXT = '#FFFFFF'  # WHITE for title or URL in progress
+        TEXT_2 = '#959595'  # GREY for all other text messages
+        ERROR = '#FF4A1B'  # ORANGE for error text messages
+        WARN = '#dfb72f'  # YELLOW for warning text messages
+        ERROR_2 = '#EA312D'  # LIGHTRED for errors 2
+        SUCCESS = '#1EA41E'  # GREEN when it is successful
+
+    elif get.THEME in get.DARKicons:
+        BACKGROUND = '#1c2027ff'  # DARK_SLATE background color for dark theme
+        NORM_TEXT = '#FFFFFF'  # WHITE for title or URL in progress
+        TEXT_2 = '#959595'  # GREY for all other text messages
+        ERROR = '#FF4A1B'  # ORANGE for error text messages
+        WARN = '#dfb72f'  # YELLOW for warning text messages
+        ERROR_2 = '#EA312D'  # LIGHTRED for errors 2
+        SUCCESS = '#1EA41E'  # GREEN when it is successful
+
+    else:
+        BACKGROUND = '#e6e6faff'  # LAVENDER background color for light theme
+        NORM_TEXT = '#1f1f1fff'  # BLACK for title or URL in progress
+        TEXT_2 = '#778899ff'  # LIGHT_SLATE for all other text messages
+        ERROR = '#d25c07'  # ORANGE for error text messages
+        WARN = '#988313'  # YELLOW for warning text messages
+        ERROR_2 = '#c8120b'  # LIGHTRED for errors 2
+        SUCCESS = '#008000'  # DARK_GREEN when it is successful
+
+    INFO = '#31BAA7'  # CYAN for info text messages
+    DEBUG = '#3298FB'  # AZURE for debug messages
+    FAILED = '#D21814'  # RED_DEEP if failed
+    ABORT = '#A41EA4'  # VIOLET if the user stops the processes
+    # YELLOW = '#C8B72F'  # for warning text messages
+    # RED = '#ff0000ff'
+    # ORANGE_DEEP = '#E92D15'
+    # GREEN = '#008000'
+    # DARK_GREEN = '#008000'
+    # BLACK = '#242424'
+    # ------------------------------------------------------------------#
+
     def __init__(self, parent):
         """
         In the 'previous' attribute is stored an ID string used to
@@ -99,12 +140,16 @@ class Logging_Console(wx.Panel):
         self.ABORT = False  # if True set to abort current process
         self.ERROR = False  # if True, all the tasks was failed
         self.previus = None  # panel name from which it starts
-        self.logname = None  # example: Videomass_VideoConversion.log
+        self.logname = None  # example: AV_conversions.log
+        self.result = None  # result of the final process
 
         wx.Panel.__init__(self, parent=parent)
         """ Constructor """
 
-        lbl = wx.StaticText(self, label=_("Log viewing console:"))
+        infolbl = _("Output viewing console:")
+        lbl = wx.StaticText(self, label=infolbl)
+        if Logging_Console.OS != 'Darwin':
+            lbl.SetLabelMarkup("<b>%s</b>" % infolbl)
         self.OutText = wx.TextCtrl(self, wx.ID_ANY, "",
                                    style=wx.TE_MULTILINE |
                                    wx.TE_READONLY |
@@ -117,26 +162,21 @@ class Logging_Console(wx.Panel):
         self.button_stop = wx.Button(self, wx.ID_STOP, _("Abort"))
         self.button_close = wx.Button(self, wx.ID_CLOSE, "")
         sizer = wx.BoxSizer(wx.VERTICAL)
-        grid = wx.GridSizer(1, 2, 5, 5)
+        grid = wx.GridSizer(1, 2, 0, 0)
         sizer.Add(lbl, 0, wx.ALL, 5)
         sizer.Add(self.OutText, 1, wx.EXPAND | wx.ALL, 5)
         sizer.Add(self.ckbx_text, 0, wx.ALL, 5)
         sizer.Add(self.barProg, 0, wx.EXPAND | wx.ALL, 5)
-        sizer.Add(self.labPerc, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)
-        sizer.Add(grid, flag=wx.ALIGN_RIGHT | wx.RIGHT, border=5)
-        grid.Add(self.button_stop, 0, wx.ALL, 5)
-        grid.Add(self.button_close, 1, wx.ALL, 5)
+        sizer.Add(self.labPerc, 0, wx.ALL, 5)
+        sizer.Add(grid, flag=wx.ALIGN_RIGHT | wx.RIGHT, border=0)
+        grid.Add(self.button_stop, 0, wx.EXPAND | wx.ALL, 5)
+        grid.Add(self.button_close, 0, wx.EXPAND | wx.ALL, 5)
         # set_properties:
-        if OS == 'Darwin':
-            self.OutText.SetFont(wx.Font(12, wx.MODERN, wx.NORMAL, wx.NORMAL))
-        else:
-            self.OutText.SetFont(wx.Font(9, wx.MODERN, wx.NORMAL, wx.NORMAL))
-
+        self.OutText.SetBackgroundColour(Logging_Console.BACKGROUND)
         self.ckbx_text.SetToolTip(_('If activated, hides some '
                                     'output messages.'))
         self.button_stop.SetToolTip(_("Stops current process"))
         self.SetSizerAndFit(sizer)
-
         # bind
         self.Bind(wx.EVT_BUTTON, self.on_stop, self.button_stop)
         self.Bind(wx.EVT_BUTTON, self.on_close, self.button_close)
@@ -169,7 +209,7 @@ class Logging_Console(wx.Panel):
         self.logname = varargs[8]  # example: Videomass_VideoConversion.log
         time_seq = self.parent.time_seq  # a time segment
 
-        write_log(self.logname, LOGDIR)  # set initial file LOG
+        write_log(self.logname, Logging_Console.LOGDIR)  # set initial file LOG
 
         if varargs[0] == 'onepass':  # from Audio/Video Conv.
             self.PARENT_THREAD = OnePass(varargs, duration,
@@ -202,45 +242,44 @@ class Logging_Console(wx.Panel):
         pubsub "UPDATE_YDL_FROM_IMPORT_EVT" .
         """
         if status == 'ERROR':
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.Colour(YELLOW)))
+            self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.ERROR))
             self.OutText.AppendText('%s\n' % output)
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.NullColour))
-
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.Colour(RED)))
-            self.OutText.AppendText(_(' ...Failed\n'))
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.NullColour))
+            self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.FAILED))
+            self.OutText.AppendText(Logging_Console.MSG_failed)
+            self.result = 'failed'
 
         elif status == 'WARNING':
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.Colour(YELLOW)))
+            self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.WARN))
             self.OutText.AppendText('%s\n' % output)
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.NullColour))
 
         elif status == 'DEBUG':
             if '[download] Destination' in output:
-                self.OutText.SetDefaultStyle(wx.TextAttr(wx.Colour(YELLOW)))
+                self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.DEBUG))
+                self.OutText.AppendText('%s\n' % output)
+
+            elif '[info]' in output:
+                self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.INFO))
                 self.OutText.AppendText('%s\n' % output)
-                self.OutText.SetDefaultStyle(wx.TextAttr(wx.NullColour))
 
             elif '[download]' not in output:
-                self.OutText.SetDefaultStyle(wx.TextAttr(wx.Colour(YELLOW)))
+                self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.TEXT_2))
                 self.OutText.AppendText('%s\n' % output)
-                self.OutText.SetDefaultStyle(wx.TextAttr(wx.NullColour))
 
-                with open(os.path.join(LOGDIR, self.logname), "a") as logerr:
-                    logerr.write("[YOUTUBE_DL]: %s > %s\n" % (status,
-                                                                  output))
+                with open(os.path.join(Logging_Console.LOGDIR,
+                                       self.logname), "a") as logerr:
+                    logerr.write("[YOUTUBE_DL]: %s > %s\n" % (status, output))
         elif status == 'DOWNLOAD':
             self.labPerc.SetLabel("%s" % duration[0])
             self.barProg.SetValue(duration[1])
 
         elif status == 'FINISHED':
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.Colour(YELLOW)))
+            self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.TEXT_2))
             self.OutText.AppendText('%s\n' % duration)
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.NullColour))
 
         if status in ['ERROR', 'WARNING']:
-            with open(os.path.join(LOGDIR, self.logname), "a") as logerr:
-                    logerr.write("[YOUTUBE_DL]: %s\n" % (output))
+            with open(os.path.join(Logging_Console.LOGDIR,
+                                   self.logname), "a") as logerr:
+                logerr.write("[YOUTUBE_DL]: %s\n" % (output))
     # ---------------------------------------------------------------------#
 
     def youtubedl_exec(self, output, duration, status):
@@ -251,10 +290,13 @@ class Logging_Console(wx.Panel):
         """
         if not status == 0:  # error, exit status of the p.wait
             if output:
-                self.OutText.AppendText('%s\n' % output)
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.Colour(RED)))
-            self.OutText.AppendText(_(' ...Failed\n'))
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.NullColour))
+                if 'ERROR:' in output:
+                    self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.ERROR))
+                    self.OutText.AppendText('%s\n' % output)
+
+            self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.ERROR_2))
+            self.OutText.AppendText(Logging_Console.MSG_failed)
+            self.result = 'failed'
             return
 
         if '[download]' in output:  # ...in processing
@@ -262,21 +304,27 @@ class Logging_Console(wx.Panel):
                 try:
                     i = float(output.split()[1].split('%')[0])
                 except ValueError:
+                    self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.WARN))
                     self.OutText.AppendText(' %s' % output)
                 else:
-                    # if not self.ckbx_text.IsChecked():# not print output
-                    #    self.OutText.AppendText(' %s' % output)
                     self.barProg.SetValue(i)
                     self.labPerc.SetLabel("%s" % output)
                     del output, duration
 
         else:  # append all others lines on the textctrl and log file
             if not self.ckbx_text.IsChecked():  # not print the output
-                self.OutText.SetDefaultStyle(wx.TextAttr(wx.Colour(YELLOW)))
-                self.OutText.AppendText(' %s' % output)
-                self.OutText.SetDefaultStyle(wx.TextAttr(wx.NullColour))
+                if '[info]' in output:
+                    self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.INFO))
+                    self.OutText.AppendText(' %s' % output)
+                elif 'WARNING:' in output:
+                    self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.WARN))
+                    self.OutText.AppendText(' %s' % output)
+                elif 'ERROR:' not in output:
+                    self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.TEXT_2))
+                    self.OutText.AppendText(' %s' % output)
 
-            with open(os.path.join(LOGDIR, self.logname), "a") as logerr:
+            with open(os.path.join(Logging_Console.LOGDIR,
+                                   self.logname), "a") as logerr:
                 logerr.write("[YOUTUBE-DL]: %s" % (output))
                 # write a row error into file log
 
@@ -293,7 +341,7 @@ class Logging_Console(wx.Panel):
         NOTE: During conversion the ffmpeg errors do not stop all
               others tasks, if an error occurred it will be marked
               with 'failed' but continue; if it has finished without
-              errors it will be marked with 'completed' on update_count
+              errors it will be marked with 'done' on update_count
               method. Since not all ffmpeg messages are errors, sometimes
               it happens to see more output marked with yellow color.
 
@@ -306,23 +354,23 @@ class Logging_Console(wx.Panel):
         #    self.OutText.AppendText(output)
 
         if not status == 0:  # error, exit status of the p.wait
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.Colour(RED)))
-            self.OutText.AppendText(_(' ...Failed\n'))
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.NullColour))
+            self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.ERROR_2))
+            self.OutText.AppendText(Logging_Console.MSG_failed)
+            self.result = 'failed'
             return  # must be return here
 
         if 'time=' in output:  # ...in processing
             i = output.index('time=')+5
-            pos = output[i:i+8].split(':')
-            hours, minutes, seconds = pos[0], pos[1], pos[2]
-            timesum = (int(hours) * 3600 + int(minutes)) * 60 + int(seconds)
-            self.barProg.SetValue(timesum)
-            percentage = timesum / duration * 100
+            pos = output[i:].split()[0]
+            ms = get_milliseconds(pos)
+            self.barProg.SetValue(ms)
+            percentage = round((ms / duration) * 100 if duration != 0 else 100)
             out = [a for a in "=".join(output.split()).split('=') if a]
             ffprog = []
             for x, y in pairwise(out):
                 ffprog.append("%s: %s | " % (x, y))
-            remaining = time_human(duration-timesum)
+
+            remaining = milliseconds2timeformat(duration - ms)
             self.labPerc.SetLabel("Processing... %s%% | %sTime Remaining: %s" %
                                   (str(int(percentage)), "".join(ffprog),
                                    remaining)
@@ -331,10 +379,25 @@ class Logging_Console(wx.Panel):
 
         else:  # append all others lines on the textctrl and log file
             if not self.ckbx_text.IsChecked():  # not print the output
-                self.OutText.SetDefaultStyle(wx.TextAttr(wx.Colour(YELLOW)))
-                self.OutText.AppendText('%s' % output)
-                self.OutText.SetDefaultStyle(wx.TextAttr(wx.NullColour))
-            with open(os.path.join(LOGDIR, self.logname), "a") as logerr:
+                if [x for x in ('info', 'Info') if x in output]:
+                    self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.INFO))
+                    self.OutText.AppendText('%s' % output)
+
+                elif [x for x in ('Failed', 'failed', 'Error', 'error')
+                      if x in output]:
+                    self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.ERROR))
+                    self.OutText.AppendText('%s' % output)
+
+                elif [x for x in ('warning', 'Warning') if x in output]:
+                    self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.WARN))
+                    self.OutText.AppendText('%s' % output)
+
+                else:
+                    self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.TEXT_2))
+                    self.OutText.AppendText('%s' % output)
+
+            with open(os.path.join(Logging_Console.LOGDIR,
+                                   self.logname), "a") as logerr:
                 logerr.write("[FFMPEG]: %s" % (output))
                 # write a row error into file log
     # ----------------------------------------------------------------------
@@ -346,23 +409,18 @@ class Logging_Console(wx.Panel):
 
         """
         if end == 'ok':
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.Colour(GREEN)))
-            self.OutText.AppendText(_(' ...Completed\n'))
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.NullColour))
-            lab = "%s" % self.labPerc.GetLabel()
-            if lab.split('|')[0] == 'Processing... 99% ':
-                relab = lab.replace('Processing... 99%', 'Processing... 100%')
-                self.labPerc.SetLabel(relab)
+            self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.SUCCESS))
+            self.OutText.AppendText(Logging_Console.MSG_done)
             return
         # if STATUS_ERROR == 1:
         if end == 'error':
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.Colour(YELLOW)))
+            self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.WARN))
             self.OutText.AppendText('\n%s\n' % (count))
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.NullColour))
             self.ERROR = True
         else:
             self.barProg.SetRange(duration)  # set la durata complessiva
             self.barProg.SetValue(0)  # resetto la prog bar
+            self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.NORM_TEXT))
             self.OutText.AppendText('\n%s : "%s"\n' % (count, fname))
 
     # ----------------------------------------------------------------------
@@ -371,19 +429,22 @@ class Logging_Console(wx.Panel):
         At the end of the process
         """
         if self.ERROR is True:
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.Colour(RED)))
-            self.OutText.AppendText(_('\n Sorry, task failed !\n'))
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.NullColour))
+            self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.ERROR_2))
+            self.OutText.AppendText(Logging_Console.MSG_taskfailed)
 
         elif self.ABORT is True:
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.Colour(VIOLET)))
-            self.OutText.AppendText(_('\n Interrupted Process !\n'))
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.NullColour))
+            self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.ABORT))
+            self.OutText.AppendText(Logging_Console.MSG_interrupted)
 
         else:
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.Colour(AZURE)))
-            self.OutText.AppendText(_('\n All finished !\n'))
-            self.OutText.SetDefaultStyle(wx.TextAttr(wx.NullColour))
+            if not self.result:
+                endmsg = Logging_Console.MSG_completed
+                self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.NORM_TEXT))
+            else:
+                endmsg = Logging_Console.MSG_unfinished
+                self.OutText.SetDefaultStyle(wx.TextAttr(Logging_Console.WARN))
+            self.parent.statusbar_msg(_('...Finished'), None)
+            self.OutText.AppendText(endmsg)
             self.barProg.SetValue(0)
 
         self.button_stop.Enable(False)
@@ -398,7 +459,7 @@ class Logging_Console(wx.Panel):
         self.PARENT_THREAD.stop()
         self.parent.statusbar_msg(_("wait... I'm aborting"), 'GOLDENROD')
         self.PARENT_THREAD.join()
-        self.parent.statusbar_msg(_("Status: Interrupted"), None)
+        self.parent.statusbar_msg(_("...Interrupted"), None)
         self.ABORT = True
 
         event.Skip()
@@ -432,6 +493,7 @@ class Logging_Console(wx.Panel):
         self.ABORT = False
         self.ERROR = False
         self.logname = None
+        self.result = None
         # self.OutText.Clear()
         # self.labPerc.SetLabel('')
         self.parent.panelShown(self.previus)  # retrieve at previusly panel
